var _storedInfo;

import { getConfig } from './config.js';
var FIELDS = {
  clientId: 'client_id',
  sessionId: 'session_id'
};
var storedInfo = (_storedInfo = {}, _storedInfo[FIELDS.clientId] = null, _storedInfo[FIELDS.sessionId] = null, _storedInfo);

var loadScript = function loadScript(src) {
  return new Promise(function (resolve, reject) {
    var s = document.createElement('script');
    s.src = src;
    s.onload = resolve;
    s.onerror = reject;
    document.head.appendChild(s);
  });
};

export var loadGoogleAnalytics = function loadGoogleAnalytics() {
  var googleAnalyticsMeasurementId = getConfig('googleAnalyticsMeasurementId'); // 1. Check we have the needed config to load the script

  if (!googleAnalyticsMeasurementId) return Promise.resolve(false); // 2. Create Gtag script

  var gtagScript = "https://www.googletagmanager.com/gtag/js?id=" + googleAnalyticsMeasurementId; // 3. Load Gtag and retrieve async clientId from Google

  return loadScript(gtagScript);
};

var getGoogleField = function getGoogleField(field) {
  var googleAnalyticsMeasurementId = getConfig('googleAnalyticsMeasurementId'); // If googleAnalyticsMeasurementId is not present, then don't load anything

  if (!googleAnalyticsMeasurementId) return Promise.resolve();
  return new Promise(function (resolve) {
    // try to get the field from the stored info
    if (storedInfo[field]) return resolve(storedInfo[field]); // if not, get from the GoogleAnalytics tag

    window.gtag == null ? void 0 : window.gtag('get', googleAnalyticsMeasurementId, field, function (id) {
      // store locally field value
      storedInfo[field] = id; // resolve the promise with the field

      resolve(id);
    });
  });
};

export var setGoogleConsentMode = function setGoogleConsentMode(hasConsents) {// Disabled for now until we activate Consent Mode
  // const value = hasConsents ? 'granted' : 'denied'
  // window.gtag?.('consent', 'update', {
  //   analytics_storage: value,
  //   ad_storage: value
  // })
  // window.gtag?.('set', {
  //   allow_google_signals: hasConsents,
  //   restricted_data_processing: !hasConsents
  // })
};
export var getGoogleClientID = function getGoogleClientID() {
  return getGoogleField(FIELDS.clientId);
};
export var getGoogleSessionID = function getGoogleSessionID() {
  return getGoogleField(FIELDS.sessionId);
};